@@ -218,6 +218,17 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding) {
       "  convertToR /id get 1 add convertToR exch /id exch put",
       "  (</path>\n\n) print",
       "} def",
+      "/myeofill {",
+      "  (<path type='eofill') print",
+      "  ( id=') print convertToR /id get str cvs print ('>\n) print",
+      "  (\t<context>\n) print",
+      "  printcol",
+      "  printstyle",
+      "  (\t</context>\n\n) print",
+      "  pathforall",
+      "  convertToR /id get 1 add convertToR exch /id exch put",
+      "  (</path>\n\n) print",
+      "} def",
       "/mytext {",
       "  (<text ) print",
       "  ( id=') print convertToR /id get str cvs print (') print",
@@ -340,7 +351,7 @@ PScaptureHead <- function(file, charpath, charpos, setflat, encoding) {
       "} def",
       "/eofill {",
       "  flattenpath {mymove} {myline} {mycurve} {myclose}",
-      "  myfill",
+      "  myeofill",
       "  newpath",
       "} def",
 
